@@ -3,12 +3,11 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Apply melodic inversion to a series of notes
 
-our $VERSION = '0.0106';
+our $VERSION = '0.0200';
 
 use Data::Dumper::Compact qw(ddc);
 use List::SomeUtils qw(first_index);
 use Music::Scales qw(get_scale_notes is_scale);
-use Music::Note;
 use Moo;
 use strictures 2;
 use namespace::clean;
@@ -57,13 +56,8 @@ sub intervals {
 
     my @pitches;
 
-    if ($self->scale_name eq 'chromatic') {
-        @pitches = map { Music::Note->new($_, 'ISO')->format('midinum') } @$notes;
-    }
-    else {
-        for my $note (@$notes) {
-            push @pitches, first_index { $_ eq $note } @{ $self->_scale };
-        }
+    for my $note (@$notes) {
+        push @pitches, first_index { $_ eq $note } @{ $self->_scale };
     }
     print 'Pitches: ', ddc(\@pitches) if $self->verbose;
 
@@ -117,7 +111,7 @@ Music::MelodicDevice::Inversion - Apply melodic inversion to a series of notes
 
 =head1 VERSION
 
-version 0.0106
+version 0.0200
 
 =head1 SYNOPSIS
 
